<?php

require __DIR__."/autoloader.php";
require __DIR__."/vendor/autoload.php";
require __DIR__."/vendor/zeedhi/framework/bootstrap.php";
require __DIR__ . "/vendor/teknisa/libraries/scripts/bootstrap.php";
require __DIR__ . "/vendor/zeedhi/dataexporter/bootstrap.php";

$instanceManager = \Zeedhi\Framework\DependencyInjection\InstanceManager::getInstance();

$environment = __DIR__.'/../../../backend/config/environment.xml';
$db = __DIR__.'/../../../backend/config/db.xml';
$report = __DIR__.'/../../../backend/config/report.xml';
$parameters = __DIR__.'/../../../backend/config/parameters.xml';
$general = __DIR__.'/../../../backend/config/general.xml';

if (realpath($parameters)) {
    $instanceManager->loadFromFile($parameters);
}

$container = $instanceManager->getContainer();

$routes = array();
$routes[] = __DIR__ . '/vendor/teknisa/libraries/libRoutes.json';
$routes[] = __DIR__ . "/vendor/zeedhi/preferences/routes.json";
$routes[] = __DIR__ . '/config/routes.json';
$routes[] = __DIR__ . "/vendor/zeedhi/preferences/routes.json";
$routes[] = __DIR__ . '/vendor/zeedhi/dataexporter/routes.json';

if ($container->hasParameter('use_zhu_acl') && $container->getParameter('use_zhu_acl')){
    $acl = __DIR__ . '/../../acl/backend/config/acl.xml';
    if(realpath($acl)){
        $instanceManager->loadFromFile($acl);
    }
    require __DIR__ . "/vendor/zeedhi/zhuaclbackend/service/bootstrap.php";
    $routes[] = __DIR__."/vendor/zeedhi/zhuaclbackend/config/routes.json";
}

if ($container->hasParameter('use_zhu_update') && $container->getParameter('use_zhu_update') == 'true'){
    $zhu = __DIR__ . '/../../acl/backend/config/zhuUpdate.xml';

    if(realpath($zhu)){
        $instanceManager->loadFromFile($zhu);
    }
}

if ($container->hasParameter('use_zhu_log') && $container->getParameter('use_zhu_log')) {
    $zhuDateFormat = $container->getParameter('zhuLogDateFormat');
    $ignoredRoutes = $container->hasParameter('logIgnoredRoutes') ? $container->getParameter('logIgnoredRoutes') : [];

    require __DIR__ . "/vendor/zeedhi/zhulog/config/bootstrap.php";
    $routes[] = __DIR__."/vendor/zeedhi/zhulog/config/routes.json";

    $log = __DIR__.'/../../acl/backend/config/log.xml';
    if(realpath($log)){
        $instanceManager->loadFromFile($log);
    }

    $libLog = __DIR__.'/vendor/teknisa/libraries/zhuLog.xml';
    if(realpath($libLog)){
        $instanceManager->loadFromFile($libLog);
    }

    $container->setParameter('logIgnoredRoutes', $ignoredRoutes);
    $container->setParameter('zhuLogDateFormat', $zhuDateFormat);
}

if(!realpath($db)) {
    $db = __DIR__ . "/config/db.xml";
}
if(!realpath($report)) {
    $report = __DIR__ . "/config/report.xml";
}
if (realpath($general)){
    $instanceManager->loadFromFile($general);
}

if(realpath($environment))
    $instanceManager->loadFromFile($environment);

$instanceManager->loadFromFile($db);
$instanceManager->loadFromFile(__DIR__ . '/config/environment.xml');
$instanceManager->loadFromFile(__DIR__ . '/config/controllers.xml');
$instanceManager->loadFromFile(__DIR__ . '/config/services.xml');
$instanceManager->loadFromFile(__DIR__ . "/vendor/zeedhi/preferences/services.xml");
if(realpath($report)) {
    $instanceManager->loadFromFile($report);
}

$instanceManager->registerService('routeParser', new \Zeedhi\Framework\Routing\Parsers\JSONFormat($routes));
$instanceManager->compile();